import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import PropTypes from 'prop-types';
import LayoutGridItem from './gridItem';
import cx from 'classnames';
import { ALIGN_ITEMS, BASE_CLASS, JUSTIFY_CONTENT, GUTTER_VALUES, BREAKPOINTS } from './settings';
import { jsx as _jsx } from "react/jsx-runtime";

var transition = function transition(_ref) {
  var isGapless = _ref.isGapless,
      oldProps = _objectWithoutPropertiesLoose(_ref, ["isGapless"]);

  var gutter = oldProps.gutter || isGapless ? 0 : undefined;
  return _extends({
    gutter: gutter
  }, oldProps);
};

var getGutterClassNames = function getGutterClassNames(gutterConfig) {
  if (gutterConfig === void 0) {
    gutterConfig = {};
  }

  if (GUTTER_VALUES.includes(gutterConfig)) {
    return BASE_CLASS + "--gutter-" + BREAKPOINTS.XXS + "-" + gutterConfig;
  } else if (typeof gutterConfig === 'object') {
    return Object.entries(gutterConfig).map(function (_ref2) {
      var key = _ref2[0],
          value = _ref2[1];
      return Object.values(BREAKPOINTS).includes(key) ? BASE_CLASS + "--gutter-" + key + "-" + value : null;
    }).filter(function (value) {
      return value !== null;
    }).join(' ');
  }

  return null;
};

function LayoutGrid(props) {
  var _transition = transition(props),
      alignItems = _transition.alignItems,
      children = _transition.children,
      justifyContent = _transition.justifyContent,
      gutter = _transition.gutter;

  var classNames = cx("" + BASE_CLASS, alignItems && BASE_CLASS + "--ai-" + alignItems, justifyContent && BASE_CLASS + "--jc-" + justifyContent, getGutterClassNames(gutter));
  return /*#__PURE__*/_jsx("div", {
    className: classNames,
    children: children
  });
}

LayoutGrid.displayName = 'LayoutGrid';
export default LayoutGrid;
export { LayoutGridItem, ALIGN_ITEMS as LayoutGridAlignItems, JUSTIFY_CONTENT as LayoutGridJustifyContent, GUTTER_VALUES as LayoutGridGutterValues, BREAKPOINTS as LayoutGridBreakpoints };